#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

# Tags navigation (/tags/Pouet)

use strict;
use utf8;

use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use URI::Escape qw(uri_escape);

use lib '/usr/share/vhffs/api';

use Vhffs::Panel::Tag;
use Vhffs::Panel::Public;
use Vhffs::Panel::Commons;

my $panel = new Vhffs::Panel::Public();

my $cgi = $panel->{cgi};


my $search = Encode::decode_utf8($cgi->param('search'));
# TODO Handle complicated search patterns
my ($category, $tag) = split /::/, $search;
unless(defined $tag) {
	$tag = $category;
	$category = undef;
}

# current page
my $page = defined($cgi->param('page')) ? int($cgi->param('page')) : 1;

my ($groups, $count) = Vhffs::Panel::Tag::get_groups($panel->{vhffs}, $category, $tag, $page - 1);

if(scalar(@$groups) == 0) {
	$panel->render('common/error.tt', {
		message => gettext('No group found')
	});
	exit(0);
}

my $url = $panel->{url};
$url =~ s!tags/.*!tagsearch.pl!;

my $pager = Vhffs::Panel::Commons::get_pager($page, $count, 10, 5, $url, { search => uri_escape($search)});

my $vars = {
	groups => $groups,
	gs_title => gettext( 'Search results' ),
	gs_pager => $pager
};

$panel->render('content/groupsearch-results.tt', $vars);
