#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

use POSIX qw(locale_h);
use locale;
use Locale::gettext;

use lib '/usr/share/vhffs/api';
use Vhffs::User;
use Vhffs::Panel::Public;

my $panel = new Vhffs::Panel::Public();
my $cgi = $panel->{cgi};
my $vhffs = $panel->{vhffs};
my $config = $vhffs->get_config();

my $username = $cgi->param('name');

unless(defined $username) {
	$panel->render('common/error.tt', {
		message => gettext('CGI Error')
	});
	exit(0);
}

my $user = Vhffs::User::get_by_username($panel->{vhffs}, $username);

unless(defined $user) {
	$panel->render('common/error.tt', {
		message => gettext('User not found')
	});
	exit(0);
}

my @groups;
foreach my $grouphash (@{$user->get_groups}) {
	push @groups, $grouphash->{groupname};
}
$user->{groups} = \@groups;

my $vars = {
	user => $user,
};

$panel->render('content/user-details.tt', $vars);
